@@ -12,8 +12,8 @@ class Person:
     ----------
     age: int
         âge de l'individu
-    male: int
-        prend la valeur 1 si l'individu est un homme
+    male: bool
+        prend la valeur True si l'individu est un homme
     earn: float
         revenu de travail
     rpp: float
@@ -25,7 +25,7 @@ class Person:
     prev_cap_losses: float
         pertes en capital nettes d'autres années (avec facteur d'inclusion partielle déjà appliqué)
     cap_gains_exempt: float
-        exonération des gains en capital admissibiles demandée (sur gains en capital nets); soumis à un plafond à vie
+        exonération des gains en capital admissibles demandée (sur gains en capital nets); soumis à un plafond à vie
     othtax: float
         autre revenu imposable
     othntax: float
@@ -41,7 +41,7 @@ class Person:
     con_rrsp: float
         cotisation REER
     con_non_rrsp: float
-        contisation autre que REER (p.ex. à un CELI ou à des comptes non enregistrés)
+        cotisation autre que REER (p.ex. à un CELI ou à des comptes non enregistrés)
     con_rpp: float
         cotisation à un régime de pension agréé (RPA)
     union_dues: float
@@ -51,25 +51,25 @@ class Person:
     gift: float
         dons de biens culturels et écosensibles
     years_can: int
-        nombre d'années vécues au Canada lorsque la Pension de la sécurité de la vieillesse (PSV) est demandée
+        nombre d'années vécues au Canada depuis l’âge de 18 ans lorsque la Pension de la sécurité de la vieillesse (PSV) est demandée
     disabled: boolean
-        statut d'invalidité
+        statut d'invalidité selon les règles fiscales (le même statut est utilisé pour l'ensemble des mesures fiscales modélisées)
     widow: boolean
-        statut de veuf/veuve
+        statut de veuf/veuve selon le Programme de la sécurité de la vieillesse
     med_exp: float
-        montant des dépenses en santé admissibles
+        montant des dépenses en santé admissibles selon les règles fiscales (le même montant est utilisé pour tous les paliers de gouvernement)
     ndays_chcare_k1: float
         nombre de jours de garde du premier enfant
     ndays_chcare_k2: float
         nombre de jours de garde du second enfant
     asset: float
-        valeur marchande des actifs (illiquides)
+        valeur marchande des actifs (avoirs liquides) comptabilisés aux fins d'admissibilité à l'aide sociale (vérifier la définition selon la province)
     oas_years_post: int
         nombre d'années de report pour la PSV (après 65 ans)
     months_cerb_cesb: int
         nombre de mois pour lesquels la PCU ou la PCUE est demandée
     student: boolean
-        statut d'étudiant ou fin des études après décembre 2019 (pour PCUE)
+        statut d'étudiant aux fins d'admissibilité à la PCUE
     essential_worker: boolean
         True si travailleur essentiel (au Québec seulement)
     hours_month: float
@@ -77,9 +77,17 @@ class Person:
     prev_inc_work: float
         revenu du travail de l'année précédente
     dep_senior: boolean
-        True si la personne aînée n'est pas autonome
+        True si la personne aînée n'est pas autonome aux du crédit d'impôt pour maintien à domicile des aînés
     home_support_cost: float
-        coût du maintien à domicile
+        dépenses engagées pour des services de maintien à domicile rendus ou à être rendus à partir du jour du 70e anniversaire
+    months_ei: int
+        nombre de mois pour lesquels l'Assurance-Emploi sont demandée
+    months_crb: int
+        nombre de mois pour lesquels la PCRE est demandée
+    pub_drug_insurance: boolean
+        True si la personne doit cotiser à l'Assurance médicaments du Québec (pas d'assurance médicaments privée)
+    tax_shield: boolean
+        True si la personne demande le crédit d'impôt bouclier ficscal au Québec
     """
     def __init__(self, age=50, male=True, earn=0, rpp=0, cpp=0,
                  net_cap_gains=0, prev_cap_losses=0, cap_gains_exempt=0,
@@ -89,8 +97,8 @@ class Person:
                  disabled=False, widow=False, med_exp=0, ndays_chcare_k1=0,
                  ndays_chcare_k2=0, asset=0, oas_years_post=0,
                  months_cerb_cesb=0, student=False, essential_worker=False,
-                 hours_month=None, prev_inc_work=None,
-                 dep_senior=False, home_support_cost=0):
+                 emp_temp_constraints=False, hours_month=None, prev_inc_work=None,
+                 dep_senior=False, home_support_cost=0,months_ei=0, months_crb =0, pub_drug_insurance=False, tax_shield=False):
         self.age = age
         self.male = male
         self.attach_inc_work_month(earn, self_earn)
@@ -111,17 +119,22 @@ class Person:
         self.union_dues = union_dues
         self.donation = donation
         self.gift = gift
-        self.years_can = age if years_can is None else years_can  # number of years in Canada (max = 40)
+        self.years_can = max(0,age-18) if years_can is None else years_can  # number of years in Canada (max = 40)
         self.disabled = disabled
         self.widow = widow
         self.med_exp = med_exp
         self.ndays_chcare_k1 = ndays_chcare_k1  # should be the kid with the most days,
         self.ndays_chcare_k2 = ndays_chcare_k2  # second kid with most days, in same order for both spouses
         self.asset = asset
+        self.months_crb = months_crb
+        self.months_ei = months_ei
         self.oas_years_post = oas_years_post
         self.compute_months_cerb_cesb(months_cerb_cesb, student)
+        self.pub_drug_insurance = pub_drug_insurance
+        self.tax_shield = tax_shield
         self.student = student
         self.essential_worker = essential_worker
+        self.emp_temp_constraints = emp_temp_constraints 
         self.hours_month = hours_month  # could enter list of hours for ei
         self.dep_senior = dep_senior
         self.home_support_cost = home_support_cost
@@ -132,11 +145,12 @@ class Person:
         self.inc_oas = 0
         self.inc_gis = 0
         self.inc_ei = 0
-        self.inc_social_ass = 0
+        self.inc_sa = 0
         self.allow_couple = 0
         self.allow_surv = 0
         self.inc_cerb = 0
         self.inc_cesb = 0
+        self.inc_crb = 0
         self.inc_iprew = 0
         self.covid = None
         self.after_tax_inc = None
@@ -202,8 +216,8 @@ class Person:
         float
             Revenu de travail.
         """
-        return self.inc_earn + self.inc_self_earn \
-            + self.inc_cerb + self.inc_cesb + self.inc_iprew
+        return self.inc_earn + self.inc_self_earn
+            
 
     @property
     def inc_non_work(self):
@@ -217,8 +231,9 @@ class Person:
         """
         return (self.inc_rpp + self.inc_cpp + self.inc_othtax
                 + self.inc_othntax + self.inc_rrsp + self.inc_oas
-                + self.inc_gis + self.inc_ei + self.net_cap_gains
-                + self.div_elig + self.div_other_can)
+                + self.inc_gis + self.allow_couple + self.allow_surv
+                + self.inc_ei + self.net_cap_gains
+                + self.div_elig + self.div_other_can + self.inc_cerb + self.inc_cesb + self.inc_iprew + self.inc_crb)
 
     @property
     def inc_tot(self):
@@ -285,16 +300,16 @@ class Dependent:
     disa: boolean
         statut d'invalidité
     child_care: float
-        montant des dépenses réelles de frais de garde
+        dépenses réelles de frais de garde
     school: float
-        montant des dépenses de scolarité
+        dépenses de scolarité
     home_care: float
-        montant de l'aide à domicile
+        dépenses engagées pour des services de maintien à domicile rendus ou à être rendus à partir du jour du 70e anniversaire
     med_exp: float
-        montant des dépenses en santé admissibles
+        dépenses en santé admissibles
     """
 
-    def __init__(self, age, disa=None, child_care=0, school=None,
+    def __init__(self, age, disa=False, child_care=0, school=None,
                  home_care=None, med_exp=0):
         self.age = age
         self.disa = disa
@@ -321,11 +336,12 @@ class Hhold:
     n_adults_in_hh: int
         nombre d'adultes (18 ans et plus) dans le ménage
     """
-    def __init__(self, first, second=None, prov='qc', n_adults_in_hh=None):
+    def __init__(self, first, second=None, prov='qc', n_adults_in_hh=None, prev_fam_net_inc_prov=None):
         self.sp = [first]
         self.couple = bool(second)
         if self.couple:
             self.sp.append(second)
+        self.prev_fam_net_inc_prov = prev_fam_net_inc_prov
         self.prov = prov
         self.dep = []
         self.nkids_0_6 = 0
