@@ -12,7 +12,7 @@ def program(year):
     Parameters
     ----------
     year: int
-        année (présentement entre 2016 et 2020)
+        année (présentement entre 2016 et 2021)
     Returns
     -------
     class instance
@@ -28,6 +28,8 @@ def program(year):
         p = program_2019()
     if year == 2020:
         p = program_2020()
+    if year == 2021:
+        p = program_2021()
     return p
 
 
@@ -79,3 +81,13 @@ class program_2020(template):
     """
     def __init__(self):
         add_params_as_attr(self, module_dir + '/qpip/params/parameters_2020.csv')
+
+# program for 2021, derived from template, only requires modify
+# functions that change
+class program_2021(template):
+    """
+    Version du programme de 2021.
+    """
+
+    def __init__(self):
+        add_params_as_attr(self, module_dir + "/qpip/params/parameters_2021.csv")
