@@ -19,10 +19,9 @@ class template:
 
     def file(self, hh):
         """
-        Fonction qui permet de calculer les impôts.
+        Fonction qui permet de calculer l'impôt.
 
-        Cette fonction est celle qui calcule les déductions,
-        les crédits non-remboursables et remboursables et les impôts nets.
+        Cette fonction est celle qui calcule les déductions, les crédits non-remboursables et remboursables et l'impôt net.
 
         Parameters
         ----------
@@ -40,12 +39,18 @@ class template:
             self.calc_tax(p)
             self.calc_non_refundable_tax_credits(p, hh)
             self.div_tax_credit(p)
-            self.calc_contributions(p, hh)
-            p.prov_return['net_tax_liability'] = max(0,
-                p.prov_return['gross_tax_liability'] + p.prov_return['contributions']
-                - p.prov_return['non_refund_credits'] - p.qc_div_tax_credit)
+        for p in hh.sp:
+            p.prov_return['net_tax_liability'] = max(0, p.prov_return['gross_tax_liability'] - p.prov_return['non_refund_credits']
+                 + self.get_spouse_transfer(p, hh) - p.qc_div_tax_credit)
             self.calc_refundable_tax_credits(p, hh)
             p.prov_return['net_tax_liability'] -= p.prov_return['refund_credits']
+            self.calc_contributions(p, hh)
+            p.prov_return['net_tax_liability'] += p.prov_return['contributions']
+
+
+
+
+
 
     def calc_gross_income(self, p):
         """
@@ -62,7 +67,8 @@ class template:
                          + self.div_other_can_factor * p.div_other_can)
         p.taxable_cap_gains = self.cap_gains_rate * max(0, p.net_cap_gains)
         p.prov_return['gross_income'] = (p.inc_work + p.inc_ei + p.inc_oas
-                                         + p.inc_gis + p.inc_cpp + p.inc_rpp
+                                         + p.inc_gis + p.allow_couple
+                                         + p.allow_surv + p.inc_cpp + p.inc_rpp
                                          + p.pension_split_qc + p.taxable_div
                                          + p.taxable_cap_gains
                                          + p.inc_othtax + p.inc_rrsp)
@@ -107,7 +113,7 @@ class template:
         p.qc_work_deduc = self.work_deduc(p)
         p.qc_cpp_qpip_deduction = self.cpp_qpip_deduction(p)
         p.prov_return['deductions_gross_inc'] = (p.con_rrsp + p.con_rpp
-                                                 + p.inc_gis + p.qc_work_deduc
+                                                 + p.qc_work_deduc
                                                  + p.pension_deduction_qc
                                                  + p.qc_cpp_qpip_deduction)
 
@@ -119,11 +125,11 @@ class template:
         ----------
         p: Person
             instance de la classe Person
-        
+
         Returns
         -------
         float
-            Montant de la déduction
+            Montant de la déduction.
         """
         work_earn = p.inc_work
         if p.inc_work > 0:
@@ -133,7 +139,7 @@ class template:
 
     def cpp_qpip_deduction(self, p):
         """
-        Déduction pour les cotisations RRQ / RPC et au RQAP pour le travail autonome.
+        Déduction pour les cotisations RRQ/RPC et au RQAP pour le travail autonome.
 
         Parameters
         ----------
@@ -146,13 +152,14 @@ class template:
             Montant de la déduction.
         """
         p.qc_cpp_deduction = p.contrib_cpp_self / 2
+
         p.qc_qpip_deduction = self.qpip_deduc_rate * p.contrib_qpip_self
         return p.qc_cpp_deduction + p.qc_qpip_deduction
 
     def calc_deduc_net_income(self, p):
         """
         Fonction qui calcule les déductions suivantes:
-        1. Pertes en capital net des autres années;
+        1. Pertes en capital nettes d'autres années;
         2. Déduction pour gain en capital exonéré.
 
         Permet une déduction maximale égale aux gains en capital taxables nets.
@@ -162,8 +169,10 @@ class template:
         p: Person
             instance de la classe Person
         """
-        p.fed_return['deductions_net_inc'] = min(p.taxable_cap_gains,
-            p.prev_cap_losses + self.cap_gains_rate * p.cap_gains_exempt)
+        p.fed_return['deductions_net_inc'] = min(
+            p.taxable_cap_gains,
+            p.inc_gis + p.allow_couple + p.allow_surv
+            + p.prev_cap_losses + self.cap_gains_rate * p.cap_gains_exempt)
 
     def calc_tax(self, p):
         """
@@ -193,11 +202,24 @@ class template:
         hh: Hhold
             instance de la classe Hhold
         """
-        p.qc_age_cred = self.get_age_cred(p)
-        p.qc_living_alone_cred = self.get_living_alone_cred(p, hh)
-        p.qc_pension_cred = self.get_pension_cred(p)
-        cred_amount = p.qc_age_cred + p.qc_living_alone_cred + p.qc_pension_cred
-        p.qc_age_alone_pension = max(0, cred_amount - self.get_nrtcred_clawback(p, hh))
+        if hh.sp.index(p)==0:
+            for d in hh.sp:
+                d.qc_age_cred = self.get_pension_cred(d)
+                d.qc_age_cred = self.get_age_cred(d)
+                d.qc_living_alone_cred = self.get_living_alone_cred(p, hh)
+
+        if hh.couple==True and p.prov_return['net_income']>(0.5*hh.fam_net_inc_prov):
+            cred_amount = hh.sp[0].qc_age_cred + hh.sp[1].qc_age_cred + hh.sp[0].qc_pension_cred + hh.sp[1].qc_pension_cred
+            p.qc_age_alone_pension = max(0, cred_amount - self.get_nrtcred_clawback(p, hh))
+        elif hh.couple==True and p.prov_return['net_income']<(0.5*hh.fam_net_inc_prov):
+            p.qc_age_alone_pension = 0
+        elif hh.couple==True and p.prov_return['net_income']==(0.5*hh.fam_net_inc_prov):
+            cred_amount = hh.sp[0].qc_age_cred + hh.sp[1].qc_age_cred + hh.sp[0].qc_pension_cred + hh.sp[1].qc_pension_cred
+            hh.sp[0].qc_age_alone_pension = max(0, cred_amount - self.get_nrtcred_clawback(p, hh))
+            hh.sp[1].qc_age_alone_pension = 0
+        elif hh.couple==False:
+            cred_amount = p.qc_age_cred + p.qc_pension_cred + p.qc_living_alone_cred
+            p.qc_age_alone_pension = max(0, cred_amount - self.get_nrtcred_clawback(p, hh))
 
         p.qc_disabled_cred = self.get_disabled_cred(p)
         p.qc_med_exp_nr_cred = self.get_med_exp_cred(p, hh)
@@ -260,9 +282,10 @@ class template:
         """
         pension_split_cred = (p.inc_rpp + p.inc_rrsp - p.pension_deduction_qc
                               + p.pension_split_qc)
-        return min(self.nrtc_pension_max,
-                   pension_split_cred * self.nrtc_pension_factor)
-        
+
+        p.qc_pension_cred = min(self.nrtc_pension_max, pension_split_cred * self.nrtc_pension_factor)
+        return p.qc_pension_cred
+
     def get_nrtcred_clawback(self, p, hh):
         """
         Fonction qui calcule la récupération de la somme des crédits non-remboursables 1. en raison de l'âge; 2. pour personne vivant seule; et 3. pour revenu de retraite.
@@ -435,6 +458,25 @@ class template:
         p.qc_div_tax_credit = (self.div_elig_cred_net_rate * p.div_elig
                                + self.div_other_can_cred_net_rate * p.div_other_can)
 
+    def get_spouse_transfer(self, p, hh):
+        """
+        Fonction qui récupère le surplus des crédits non rembousables tranferables au conjoint (s'il y lieu).
+
+        Parameters
+        ----------
+        p: Person
+            instance de la classe Person
+        """
+        if not hh.couple:
+            return 0
+
+        spouse = hh.sp[1 - hh.sp.index(p)]
+        transfer = spouse.prov_return['gross_tax_liability'] - spouse.prov_return['non_refund_credits'] - spouse.qc_div_tax_credit
+        if transfer < 0:
+            return transfer
+        else:
+            return 0
+
     def calc_refundable_tax_credits(self, p, hh):
         """
         Fonction qui fait la somme des crédits remboursables.
@@ -455,10 +497,13 @@ class template:
 
         p.qc_ccap = self.ccap(p, hh)
         p.qc_solidarity = self.solidarity(p, hh)
+        p.qc_cost_of_living = self.cost_of_living(p, hh)
+        p.qc_tax_shield = self.tax_shield(p, hh)
 
-        l_all_creds = [p.qc_chcare, p.qc_witb, p.qc_home_support,
+
+        l_all_creds = [p.qc_chcare, p.qc_tax_shield, p.qc_witb, p.qc_home_support,
                        p.qc_senior_assist, p.qc_med_exp, p.qc_ccap,
-                       p.qc_solidarity]
+                       p.qc_solidarity, p.qc_cost_of_living]
         l_existing_creds = [cred for cred in l_all_creds if cred]  # removes credits not implemented
 
         p.prov_return['refund_credits'] = sum(l_existing_creds)
@@ -630,6 +675,8 @@ class template:
             return 0
         if p.inc_work < self.med_exp_min_work_inc:
             return 0
+        if hh.fam_net_inc_prov>self.med_exp_max_fam_inc:
+            return 0
 
         base = min(self.med_exp_max, self.med_exp_rate * p.qc_med_exp_nr_cred)
         clawback = self.med_exp_claw_rate * max(0, hh.fam_net_inc_prov - self.med_exp_claw_cutoff)
@@ -637,9 +684,9 @@ class template:
 
     def ccap(self, p, hh):
         """
-        Fonction qui calcule l'Allocation famille (qui s'appelait le Soutien aux enfants avant 2019).
+        Fonction qui calcule le crédit d’impôt remboursable accordant une allocation aux familles (CIRAAF) (qui s'appelait le Soutien aux enfants avant 2019).
 
-        Cette fonction calcule le montant reçu en fonction du nombre d'enfants, de la situation familiale (couple/monoparental) et du revenu.
+        Cette fonction calcule le montant reçu selon le nombre d'enfants, la situation familiale (couple/monoparental) et le revenu.
 
         Parameters
         ----------
@@ -699,8 +746,13 @@ class template:
         hh: Hhold
             instance de la classe Hhold
         """
+
         p.prov_return['contributions'] = self.add_contrib_subsid_chcare(p, hh) \
-                                         + self.health_contrib(p, hh)
+                                         + self.health_contrib(p, hh) + self.contrib_hsf(p)
+
+        if p.pub_drug_insurance:
+            p.prov_return['contributions'] += self.drug_insurance_contrib(hh)
+
 
     def health_contrib(self, p, hh):
         """
@@ -771,6 +823,60 @@ class template:
 
         return p.ndays_chcare_k1 * contrib_k1 + p.ndays_chcare_k2 * contrib_k1 / 2
 
+    def drug_insurance_contrib(self, hh):
+        """
+        Fonction qui sert à calculer la cotisation au régime d’assurance médicaments du Québec.
+
+        Parameters
+        ----------
+        hh: Hhold
+            instance de la classe Hhold
+        """
+        for p in hh.sp:
+            if p.age >= self.nrtc_age:
+                if hh.couple:
+                    if p.inc_gis >= (self.pdip_gis_rate_exempt * self.pdip_gis_max_low):
+                        return 0
+                else:
+                    if p.inc_gis >= (self.pdip_gis_rate_exempt * self.pdip_gis_max_high):
+                        return 0
+                        
+        net_inc_used = hh.fam_net_inc_prov
+
+        if hh.couple:
+            net_inc_used -= self.pdip_couple
+            if hh.nkids_0_18==1:
+                net_inc_used-= self.pdip_couple_kid1
+            elif hh.nkids_0_18>1:
+                net_inc_used -= self.pdip_couple_kid2p
+        else:
+            net_inc_used -= self.pdip_single
+            if hh.nkids_0_18==1:
+                net_inc_used -= self.pdip_single_kid1
+            elif hh.nkids_0_18>1:
+                net_inc_used -= self.pdip_single_kid2p
+
+        if net_inc_used<=0:
+            return 0
+
+        ind = np.searchsorted(self.l_pdip_brackets, net_inc_used, 'right') - 1
+
+        if net_inc_used <= self.l_pdip_brackets[ind]:
+            if hh.couple:
+                amount = net_inc_used * self.l_pdip_rates_couple[ind]
+            else:
+                amount = net_inc_used * self.l_pdip_rates_couple[ind]
+        else:
+            if hh.couple:
+                amount = min(self.l_pdip_max[ind], self.l_pdip_constant_couple[ind] + \
+                    self.l_pdip_rates_couple[ind] * (net_inc_used - self.l_pdip_brackets[ind]))
+            else:
+                amount = min(self.l_pdip_max[ind], self.l_pdip_constant_single[ind] + \
+                    self.l_pdip_rates_single[ind] * (net_inc_used - self.l_pdip_brackets[ind]))
+        amount = min(self.pdip_cutoff, amount)
+        return amount
+
+
     def solidarity(self, p, hh):
         """
         Fonction qui calcule le crédit d'impôt pour solidarité.
@@ -783,7 +889,7 @@ class template:
             instance de la classe Person
         hh: Hhold
             instance de la classe Hhold
-        
+
         Returns
         -------
         float
@@ -808,3 +914,93 @@ class template:
         net_amount_tvq = max(0, amount_tvq - self.solidarity_rate_tvq * base_claw)
         net_amount = max(net_amount_total, net_amount_tvq)
         return net_amount / (1 + hh.couple)
+
+    def cost_of_living(self, p, hh):
+        """
+       Fonction qui calcule le crédit d'impôt remboursable attribuant une prestation exceptionnelle pour pallier la hausse du coût de la vie et le crédit d'impôt remboursable attribuant un montant ponctuel pour pallier la hausse du coût de la vie.
+
+        En vigueur en 2021 seulement.
+
+        Parameters
+        ----------
+        p: Person
+            instance de la classe Person
+        hh: Hhold
+            instance de la classe Hhold
+
+        """
+
+        pass
+
+
+    def contrib_hsf(self, p):
+        """
+        Fonction qui calcule la cotisation au Fonds des services de santé (FSS).
+
+        Parameters
+        ----------
+        p: Person
+            instance de la classe Person
+        """
+        amount = p.inc_self_earn + p.inc_rpp + p.inc_cpp + p.pension_split_qc + p.taxable_cap_gains + p.inc_othtax + p.inc_rrsp - p.contrib_qpip_self
+        if amount < self.hsf_high_inc:
+            p.qc_contrib_hsf= min(self.hsf_low_cutoff, max(0,(amount - self.hsf_low_inc))*self.hsf_rate)
+        else:
+            p.qc_contrib_hsf = min(self.hsf_high_cutoff, max(0,(amount - self.hsf_high_inc))*self.hsf_rate + self.hsf_low_cutoff)
+        return p.qc_contrib_hsf
+
+    def tax_shield(self, p, hh):
+        """
+        Fonction qui calcule le crédit d'impôt Bouclier fiscal.
+
+        La part de ce crédit liée à la prime au travail est partagée proportionnellement au revenu des conjoints par rapport au revenu famillial.
+
+        Parameters
+        ----------
+        p: Person
+            instance de la classe Person
+        hh: Hhold
+            instance de la classe Hhold
+        """
+        if not p.tax_shield:
+            return 0
+        if p.prev_inc_work==None:
+            return 0
+        if hh.prev_fam_net_inc_prov == None:
+            return 0
+
+        var_fam_net_inc = max(0,hh.fam_net_inc_prov - hh.prev_fam_net_inc_prov) # 60
+        if var_fam_net_inc == 0:
+            # VOUS N'AVEZ PAS DROIT AU CREDIT D'IMPOT BOUCLIER FISCAL
+            return 0
+        modified_fam_inc = hh.fam_net_inc_prov - self.tax_shield_rate * min(sum([(min(max(0,p.inc_work - p.prev_inc_work), self.tax_shield_max_inc_variation)) for p in hh.sp]), var_fam_net_inc) # 70
+
+        # prime au travail
+        if p.qc_witb > 0:
+            if hh.couple:
+                rate = self.witb_rate_couple_dep if hh.nkids_0_18 > 0 else self.witb_rate
+                fam_witb = rate * max(0, min(self.witb_cut_inc_high_couple, hh.fam_inc_work) - self.witb_cut_inc_low_couple)
+                amount_witb = max(0,fam_witb - (self.witb_claw_rate * max(0, modified_fam_inc - self.witb_cut_inc_high_couple))) # 77
+                witb = min(self.tax_shield_max_couple, amount_witb - (p.qc_witb*hh.fam_inc_work /p.inc_work ))# 81
+            else:
+                rate = self.witb_rate_single_dep if hh.nkids_0_18 > 0 else self.witb_rate
+                fam_witb = rate * max(0, min(self.witb_cut_inc_high_single, hh.fam_inc_work) - self.witb_cut_inc_low_single)
+                amount_witb = max(0,fam_witb - (self.witb_claw_rate * max(0, modified_fam_inc - self.witb_cut_inc_high_single))) # 77
+                witb = min(self.tax_shield_max_single, amount_witb - p.qc_witb) # 81
+        else:
+            witb = 0
+        # frais de garde d'enfants
+        if p.qc_chcare > 0:
+            if hh.child_care_exp == 0:
+                chcare = 0 # heterosexual couple: mother receives benefit
+            else:
+                amount_care = min(hh.child_care_exp, hh.nkids_0_6 * self.chcare_young + hh.nkids_7_16 * self.chcare_old) # 82
+                ind = np.searchsorted(self.chcare_brack, modified_fam_inc, 'right') - 1
+                net_amount = self.chcare_rate[ind] * amount_care # 84
+
+                chcare = net_amount - p.qc_chcare # 90
+        else:
+            chcare = 0
+
+        # crédit d'impot bouclier fiscal
+        return (witb + chcare)/(1+hh.couple)  # 96
